@@ -18,9 +18,9 @@ import fontaine.charmaps.internals
 
 class Library(object):
 
-    def __init__(self):
+    def __init__(self, collections=['all']):
         self._charmaps = []
-        self.collections = ['all']
+        self.collections = collections
 
     def register(self, charmap):
         self._charmaps.append(charmap())
@@ -36,7 +36,7 @@ class Library(object):
                 extension_name = module.Extension.extension_name
             except (ImportError, AttributeError):
                 continue
-            except PackageRequiredException, ex:
+            except PackageRequiredException as ex:
                 import sys
                 sys.stderr.write(u'WARNING: %s\n' % ex.message)
                 continue
