@@ -1,6 +1,5 @@
 import errno
 import os
-import re
 
 from fontaine.ext.base import BaseExt
 
@@ -22,6 +21,13 @@ class Extension(BaseExt):
             raise OSError(errno.ENOENT, 'File [%s] does not exist' % path)
         return path
 
+    @staticmethod
+    def get_glyphs(subsetname):
+        path = os.path.join(Extension.path, subsetname) + '.txt'
+        if not os.path.exists(path):
+            return ''
+        return open(path).read()
+
     @staticmethod
     def __getcharmaps__():
         for filepath in os.listdir(Extension.path):
